Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: components/sync/engine/fake_sync_manager.h

Issue 2580033002: [Sync] Ensure that CONFIGURE_CLEAN types get unapplied before configuration (Closed)
Patch Set: Adjusted comment Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine/fake_sync_manager.h
diff --git a/components/sync/engine/fake_sync_manager.h b/components/sync/engine/fake_sync_manager.h
index 42f0c26d1932183939e1dd14e009789d783f267b..31f47440f80ccb7d52605abaae303cde972e1fad 100644
--- a/components/sync/engine/fake_sync_manager.h
+++ b/components/sync/engine/fake_sync_manager.h
@@ -42,10 +42,14 @@ class FakeSyncManager : public SyncManager {
ModelTypeSet configure_fail_types);
~FakeSyncManager() override;
- // Returns those types that have been cleaned (purged from the directory)
- // since the last call to GetAndResetCleanedTypes(), or since startup if never
- // called.
- ModelTypeSet GetAndResetCleanedTypes();
+ // Returns those types that have been purged from the directory since the last
+ // call to GetAndResetPurgedTypes(), or since startup if never called.
+ ModelTypeSet GetAndResetPurgedTypes();
+
+ // Returns those types that have been unapplied as part of purging disabled
+ // types since the last call to GetAndResetUnappliedTypes, or since startup if
+ // never called.
+ ModelTypeSet GetAndResetUnappliedTypes();
// Returns those types that have been downloaded since the last call to
// GetAndResetDownloadedTypes(), or since startup if never called.
@@ -130,8 +134,10 @@ class FakeSyncManager : public SyncManager {
// The types that should fail configuration attempts. These types will not
// have their progress markers or initial_sync_ended bits set.
ModelTypeSet configure_fail_types_;
- // The set of types that have been cleaned up.
- ModelTypeSet cleaned_types_;
+ // The set of types that have been purged.
+ ModelTypeSet purged_types_;
+ // Subset of |purged_types_| that were unapplied.
+ ModelTypeSet unapplied_types_;
// The set of types that have been downloaded.
ModelTypeSet downloaded_types_;
// The set of types that have been enabled.
« no previous file with comments | « components/sync/driver/glue/sync_backend_host_impl_unittest.cc ('k') | components/sync/engine/fake_sync_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698